==> smartclientcore7.5.6.zip: docs/constants/interfaces/interfaces/AdBreakSetup.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / AdBreakSetup

# Interface: AdBreakSetup

## Properties

<a id="adbreakposition" name="adbreakposition"></a>

### adBreakPosition?

> `optional` **adBreakPosition**: `number`

***

<a id="closer" name="closer"></a>

### closer?

> `optional` **closer**: [`SeparationClips`](constants/interfaces/interfaces/SeparationClips.md)

***

<a id="divider" name="divider"></a>

### divider?

> `optional` **divider**: [`SeparationClips`](constants/interfaces/interfaces/SeparationClips.md)

***

<a id="opener" name="opener"></a>

### opener?

> `optional` **opener**: [`SeparationClips`](constants/interfaces/interfaces/SeparationClips.md)

***

<a id="originconfig" name="originconfig"></a>

### originConfig?

> `optional` **originConfig**: `any`

***

<a id="repeat" name="repeat"></a>

### repeat?

> `optional` **repeat**: `null` \| `number`

***

<a id="requested" name="requested"></a>

### requested?

> `optional` **requested**: `boolean`

***

<a id="response" name="response"></a>

### response?

> `optional` **response**: `string`

***

<a id="responsexml" name="responsexml"></a>

### responseXML?

> `optional` **responseXML**: `null` \| `Document`

***

<a id="tag" name="tag"></a>

### tag?

> `optional` **tag**: `string` \| `string`[]

***

<a id="type" name="type"></a>

### type?

> `optional` **type**: `LINEAR` \| `NON_LINEAR`

***

<a id="urls" name="urls"></a>

### urls?

> `optional` **urls**: `string`[]

==> smartclientcore7.6.0-dev.zip: docs/constants/interfaces/interfaces/AdBreakSetup.md <==
[**smartclientcore**](README.md) • **Docs**

***

[smartclientcore](modules.md) / [constants/interfaces](constants/interfaces/README.md) / AdBreakSetup

# Interface: AdBreakSetup

## Properties

<a id="adbreakposition" name="adbreakposition"></a>

### adBreakPosition?

> `optional` **adBreakPosition**: `number`

***

<a id="closer" name="closer"></a>

### closer?

> `optional` **closer**: [`SeparationClips`](constants/interfaces/interfaces/SeparationClips.md)

***

<a id="divider" name="divider"></a>

### divider?

> `optional` **divider**: [`SeparationClips`](constants/interfaces/interfaces/SeparationClips.md)

***

<a id="opener" name="opener"></a>

### opener?

> `optional` **opener**: [`SeparationClips`](constants/interfaces/interfaces/SeparationClips.md)

***

<a id="originconfig" name="originconfig"></a>

### originConfig?

> `optional` **originConfig**: [`AdBreakSetup`](constants/interfaces/interfaces/AdBreakSetup.md)

***

<a id="repeat" name="repeat"></a>

### repeat?

> `optional` **repeat**: `null` \| `number`

***

<a id="requested" name="requested"></a>

### requested?

> `optional` **requested**: `boolean`

***

<a id="response" name="response"></a>

### response?

> `optional` **response**: `string`

***

<a id="responsexml" name="responsexml"></a>

### responseXML?

> `optional` **responseXML**: `null` \| `Document`

***

<a id="tag" name="tag"></a>

### tag?

> `optional` **tag**: `string` \| `string`[]

***

<a id="type" name="type"></a>

### type?

> `optional` **type**: `LINEAR` \| `NON_LINEAR`

***

<a id="urls" name="urls"></a>

### urls?

> `optional` **urls**: `string`[]
